@@ -23,7 +23,7 @@ from janggu.utils import _check_valid_files
 from janggu.utils import _get_genomic_reader
 from janggu.utils import _to_list
 from janggu.utils import get_genome_size_from_regions
-from janggu.version import dataversion as version
+from janggu.version import version
 
 
 def _condition_from_filename(files, conditions):
@@ -162,7 +162,7 @@ class BamLoader:
                 if process_chrom not in set(aln_file.header.references):
                     continue
                 tmp_gsize = gsize.filter_by_region(include=process_chrom)
-                length = aln_file.header.get_reference_length(process_chrom) + tmp_gsize.flank
+                length = aln_file.header.get_reference_length(process_chrom) + tmp_gsize.flank + 1
 
                 array = np.zeros((length, 2), dtype=dtype)
 
