@@ -23,6 +23,7 @@ from janggu import model_from_json
 from janggu import model_from_yaml
 from janggu import outputconv
 from janggu import outputdense
+from janggu import predict_variant_effect
 from janggu.data import Array
 from janggu.data import Bioseq
 from janggu.data import Cover
@@ -304,17 +305,59 @@ def test_janggu_influence_genomic(tmpdir):
 
     model.compile(optimizer='adadelta', loss='binary_crossentropy')
 
-    # check with some nice offset
+    # check with some simple offset
     iv = dna.gindexer[0]
     chrom, start, end = iv.chrom, iv.start, iv.end
     influence = input_attribution(model, dna, chrom=chrom, start=start, end=end)
 
     # check with an odd offset
 
-#    chrom, start, end =
     influence2 = input_attribution(model, dna, chrom=chrom, start=start-1, end=end+1)
     np.testing.assert_equal(influence[0][:], influence2[0][:][:,1:-1])
 
+    # the same, but now using the index directly
+    influence = input_attribution(model, dna, idx=0)
+
+    # check with an odd offset
+
+    influence2 = input_attribution(model, dna, chrom=chrom, start=start-1, end=end+1)
+    np.testing.assert_equal(influence[0][:], influence2[0][:][:,1:-1])
+
+
+@pytest.mark.filterwarnings("ignore:The truth value")
+def test_janggu_influence_fasta(tmpdir):
+
+    data_path = pkg_resources.resource_filename('janggu', 'resources/')
+
+    order = 1
+    filename = os.path.join(data_path, 'sample.fa')
+
+    data = Bioseq.create_from_seq('dna', fastafile=filename,
+                                 order=order, cache=False)
+
+    dna = data
+
+    @inputlayer
+    def _cnn_model(inputs, inp, oup, params):
+        layer = inputs['dna']
+        layer = Flatten()(layer)
+        output = Dense(params[0])(layer)
+        output = Dense(1, activation='sigmoid')(output)
+        return inputs, output
+
+    model = Janggu.create(_cnn_model, modelparams=(2,),
+                          inputs=data,
+                          name='dna_ctcf_HepG2-cnn')
+
+    #model.compile(optimizer='adadelta', loss='binary_crossentropy')
+
+    # check with some nice offset
+    iv = dna.gindexer[0]
+    chrom, start, end = iv.chrom, iv.start, iv.end
+    influence = input_attribution(model, dna, chrom=chrom, start=start, end=end)
+
+    influence2 = input_attribution(model, dna, idx=0)
+    np.testing.assert_equal(influence[0][:], influence2[0][:])
 
 
 @pytest.mark.filterwarnings("ignore:The truth value")
@@ -365,6 +408,52 @@ def test_janggu_variant_prediction(tmpdir):
         f.close()
 
 
+@pytest.mark.filterwarnings("ignore:The truth value")
+def test_janggu_variant_prediction_from_refgenome(tmpdir):
+    os.environ['JANGGU_OUTPUT'] = tmpdir.strpath
+    """Test Janggu creation by shape and name. """
+    data_path = pkg_resources.resource_filename('janggu', 'resources/')
+
+    for order in [1, 2, 3]:
+        refgenome = os.path.join(data_path, 'sample_genome.fa')
+        vcffile = os.path.join(data_path, 'sample.vcf')
+
+        def _cnn_model(inputs, inp, oup, params):
+            inputs = Input((50 - params['order'] + 1, 1, pow(4, params['order'])))
+            layer = Flatten()(inputs)
+            layer = Dense(params['hiddenunits'])(layer)
+            output = Dense(4, activation='sigmoid')(layer)
+            return inputs, output
+
+        model = Janggu.create(_cnn_model, modelparams={'hiddenunits':2, 'order':order},
+                              name='dna_ctcf_HepG2-cnn')
+
+        predict_variant_effect(model.kerasmodel,
+                               refgenome,
+                               vcffile,
+                               conditions=['m'+str(i) for i in range(4)],
+                               output_folder=os.path.join(os.environ['JANGGU_OUTPUT']),
+                               order=order)
+        assert os.path.exists(os.path.join(os.environ['JANGGU_OUTPUT'], 'scores.hdf5'))
+        assert os.path.exists(os.path.join(os.environ['JANGGU_OUTPUT'], 'snps.bed.gz'))
+
+        f = h5py.File(os.path.join(os.environ['JANGGU_OUTPUT'], 'scores.hdf5'), 'r')
+
+        gindexer = GenomicIndexer.create_from_file(os.path.join(os.environ['JANGGU_OUTPUT'],
+                                                                'snps.bed.gz'), None, None)
+
+        cov = Cover.create_from_array('snps', f['diffscore'],
+                                      gindexer,
+                                      store_whole_genome=True)
+
+        print(cov['chr2', 55, 65].shape)
+        print(cov['chr2', 55, 65])
+
+        assert np.abs(cov['chr2', 59, 60]).sum() > 0.0
+        assert np.abs(cov['chr2', 54, 55]).sum() == 0.0
+        f.close()
+
+
 @pytest.mark.filterwarnings("ignore:The truth value")
 def test_janggu_instance_conv(tmpdir):
     os.environ['JANGGU_OUTPUT'] = tmpdir.strpath
